#!perl

use strict;
use warnings;

use Test::More;
use Test::Deep;
use Test::Fatal;
use Path::Tiny;

use YAML qw[ LoadFile ];

use CXC::ACIS::Command::Dump qw[ loadHTML loadMIT loadDump ];


my @tags
  = @ARGV
  ? @ARGV
  : qw[
  AUALLPATCH
  TE_00124
  TE_00818
  W20000F014
  WC0010C014
  WD00001014
  WT00124014
  WT00161014
  WT0046E034
  WT00818014
];


for my $tag ( @tags ) {

    subtest "$tag" => sub {

        my $exp = LoadFile( path( qw[ t data], "${tag}.yml" ) );

        subtest 'HTML' => sub {
            my $html;
            is(
                exception { $html = path( qw[ t data ], "$tag.html" )->slurp },
                undef, 'read'
            );

            my $data;
            is( exception { $data = loadHTML( $html ) }, undef, 'parse' );

            cmp_deeply( $data, $exp, "compare data" );
        };


        subtest 'MIT' => sub {

            my $data;
            is( exception { $data = loadMIT( $tag ) }, undef, 'parse' );

            cmp_deeply( $data, $exp, "compare data" );

        };

        subtest 'dump' => sub {

            my $dump;
            is( exception { $dump = path( qw[ t data ], "$tag.dmp" )->slurp },
                undef, 'read' );

            my $data;
            is( exception { $data = loadDump( $dump ) }, undef, 'parse' );

            cmp_deeply( $data, $exp, "compare data" );

        };

    };


}

done_testing;
