#!perl

use strict;
use warnings;

use Test::More;
use Test::Deep;
use Test::Fatal;
use Path::Tiny;

use YAML qw[ LoadFile ];

use CXC::ACIS::Command::FITS qw[ loadFITS ];

my %tags = (
    WT00161014 => 'acisf051745000N003_pbk0.fits.gz',
    WT00124014 => 'acisf182941459N003_pbk0.fits.gz',
    WT00818014 => 'acisf415296872N002_pbk0.fits.gz',
    WC0010C014 => 'acisf470716340N001_pbk0.fits.gz',
    W20000F014 => 'acisf182941459N003_win0.fits.gz',
);


for my $tag ( keys %tags ) {

    subtest "$tag" => sub {

        my $exp = LoadFile( path( qw[ t data], "${tag}.yml" ) )->[0];

	delete @{$exp}{ qw/ checksum
				 commandIdentifier
				 commandLength
				 teBlockSlotIndex
				 ccBlockSlotIndex
				 windowSlotIndex
			       / };

        my $data;
        is(
            exception {

                $data = loadFITS( path( qw[ t data], $tags{$tag} )->stringify );
            },
            undef,
            "read/parse $tags{$tag}"
        );

        cmp_deeply( $data, $exp, "compare data" );

    };

}

done_testing;
